==> dogesr_0.5.0.tar.gz: dogesr/NEWS.md <==
# doges 0.5.0

Fixes:

* Some grammar and spelling fixes
* Data on doges fixed
* All families have a type now, including "Unknown" for old families

Changes:

* Adds maternal connections found in the Wikipedia
* Assigns fixed colors to every type of *casata*
* Adds vignette for using it.
* Adds family type and color information to the graph

# doges 0.4.0

Fixes:

* Adds a missing doge to the dataset
* Fixes years in office so that they match each other

Changes:

* Changes doges.years to dataset, not function
* Adds marriage.graph.slice
* marriage.graph now adds family type

# doges 0.3.0

Fixes:

* Improves documentation, some errors in code, grammar fixes
* Adds family to the two doges that didn't have one. Used the name of the doge.

Changes:

* Adds `doge.families` which is a table of all families that had a doge, and how many doges there were.

# dogesr 0.2.0

Fixes:

* Improves documentation.

Changes:

* Adds `marriage.graph` with extracts an `igraph` usable data structure from the marriage data

# dogesr 0.1.6

Fixes:

* Improves documentation, fixing some issues with inserting references.

Changes:

* Mainly for my own use, creates a `Makefile` with common tasks

# dogesr 0.1.5

Changes:

* This version adds vignettes, and some minor bug fixes. It also adds noble families data.

# dogesr 0.1.4

Changes:

* Family data included

# dogesr 0.1.3

Changes:

* Report waiting to be published at ArXiV

# dogesr 0.1.2

Changes:

* Created mainly for the vignette

# dogesr 0.1.1

Changes:

* Some bug and data fixes
* Addition of a vignette

# dogesr 0.1.0

First version including `data.doges` and `doges.years`

==> dogesr_0.5.2.tar.gz: dogesr/NEWS.md <==
# dogesr 0.5.2

Changes:
* Uses the accepted "Soldi" instead of "Soldo"
* Minor rewriting in vignettes

Fixes:
* Fixes in description

# doges 0.5.1

Changes:
* Completes some data from Wikipedia

# doges 0.5.0

Fixes:

* Some grammar and spelling fixes
* Data on doges fixed
* All families have a type now, including "Unknown" for old families

Changes:

* Adds maternal connections found in the Wikipedia
* Assigns fixed colors to every type of *casata*
* Adds vignette for using it.
* Adds family type and color information to the graph

# doges 0.4.0

Fixes:

* Adds a missing doge to the dataset
* Fixes years in office so that they match each other

Changes:

* Changes doges.years to dataset, not function
* Adds marriage.graph.slice
* marriage.graph now adds family type

# doges 0.3.0

Fixes:

* Improves documentation, some errors in code, grammar fixes
* Adds family to the two doges that didn't have one. Used the name of the doge.

Changes:

* Adds `doge.families` which is a table of all families that had a doge, and how many doges there were.

# dogesr 0.2.0

Fixes:

* Improves documentation.

Changes:

* Adds `marriage.graph` with extracts an `igraph` usable data structure from the marriage data

# dogesr 0.1.6

Fixes:

* Improves documentation, fixing some issues with inserting references.

Changes:

* Mainly for my own use, creates a `Makefile` with common tasks

# dogesr 0.1.5

Changes:

* This version adds vignettes, and some minor bug fixes. It also adds noble families data.

# dogesr 0.1.4

Changes:

* Family data included

# dogesr 0.1.3

Changes:

* Report waiting to be published at ArXiV

# dogesr 0.1.2

Changes:

* Created mainly for the vignette

# dogesr 0.1.1

Changes:

* Some bug and data fixes
* Addition of a vignette

# dogesr 0.1.0

First version including `data.doges` and `doges.years`
